@@ -4,7 +4,7 @@ use strict;
 use warnings;
 no strict 'refs';
 
-our $VERSION = '0.24_01';
+our $VERSION = '0.24_02';
 
 use Carp;
 use Exporter;
@@ -178,6 +178,9 @@ Behaves (hopefully) identically to L<URI::Split>, but roughly twice as fast.
 Unless otherwise specified, all attributes serve as full accessors, allowing
 the URI segment to be both retrieved and modified.
 
+Each attribute further has a matching clearer method (C<clear_*>) which unsets
+its value.
+
 =head2 scheme
 
 Defaults to C<file> if not present in the URI string.
